==> release.12.2.28.1.tgz: cgi-cpn/sitemaps/lib_sitemap.pm <==
#!/usr/bin/perl

# -------------------------------COMENTARIO GLOBAL---------------
# PROPOSITO.
# -----------
# Funciones utilitarias para la creación de Site Maps y News Site Maps
# ---------------------------------------------------------------
# Requiere
# use Time::Local;

use utf8;
use strict;

package lib_sitemap;

# Cantidad máxima de archivos de sitemap por index:
# Si hay más URLs que SITEMAP_NRO_MAX_PAGS en el listado, se dividen los sitemaps en múltiples archivos y se genera un index que las engloba.
# Ver https://support.google.com/webmasters/answer/75712?visit_id=637273939996212081-1472635633&rd=1
our $MAX_SITEMAP_FILES = 500; # número recomendado por google.

# Path de archivos y directorios
our $PATH_DIR = '/sitemap/';
our $XML_PAGS_INDEX = 'sitemap_pags.xml';
our $XML_PAGS_INDEX_IMAGE = 'sitemap_pags_images.xml'; # solo para sitemaps separados.
our $XML_PAGS_INDEX_VIDEO = 'sitemap_pags_videos.xml'; # solo para sitemaps separados.

our $XML_PAGS_NAME_TEMPLATE = 'sitemap_pags_%%anio_mes%%.xml';
our $XML_PAGS_NAME_TEMPLATE_IMAGE = 'sitemap_pags_images_%%anio_mes%%.xml'; # solo para sitemaps separados.
our $XML_PAGS_NAME_TEMPLATE_VIDEO = 'sitemap_pags_videos_%%anio_mes%%.xml'; # solo para sitemaps separados.

# Templates para cada sitemap de páginas
our $XML_PAGS_MOLDE1 = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\" xmlns:image=\"http://www.google.com/schemas/sitemap-image/1.1\" xmlns:video=\"http://www.google.com/schemas/sitemap-video/1.1\">\n%%content%%</urlset>\n";
# Moldes para XML de artículos con videos e imágenes.
our $XML_PAGS_MOLDE2 = "<url>\n\t<loc>%%loc%%</loc><lastmod>%%lastmod%%</lastmod>%%images%%%%videos%%\n</url>\n"; # sitemap base. Si va separado en tres sitemaps, se descartan %%images%% y %%videos%%
our $XML_PAGS_MOLDE2_IMAGE = "%%url%%<url>\n\t<loc>%%loc%%</loc><lastmod>%%lastmod%%</lastmod>%%images%%\n</url>\n%%/url%%"; # solo para sitemaps separados
our $XML_PAGS_MOLDE2_VIDEO = "%%url%%<url>\n\t<loc>%%loc%%</loc><lastmod>%%lastmod%%</lastmod>%%videos%%\n</url>\n%%/url%%"; # solo para sitemaps separados

# Templates para el index de sitemaps
our $XML_GLOBAL_MOLDE1 = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<sitemapindex xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\" xmlns:image=\"http://www.google.com/schemas/sitemap-image/1.1\" xmlns:video=\"http://www.google.com/schemas/sitemap-video/1.1\">\n%%content%%</sitemapindex>\n";
our $XML_GLOBAL_MOLDE2 = "<sitemap>\n\t<loc>%%loc%%</loc>\n\t<lastmod>%%lastmod%%</lastmod>\n</sitemap>\n";

our $XML_GLOBAL_IMAGE = "\n\t<image:image>\n\t\t<image:loc>%%loc%%</image:loc>\n\t\t<image:title>%%title%%</image:title>\n\t</image:image>";
our $XML_GLOBAL_VIDEO = "\n\t<video:video>\n\t\t<video:thumbnail_loc>%%thumbnail%%</video:thumbnail_loc>\n\t\t<video:title>%%title%%</video:title>\n\t\t<video:description>%%description%%</video:description>\n\t\t<video:content_loc>%%content_loc%%</video:content_loc>\n\t\t<video:publication_date>%%publication_date%%</video:publication_date>%%expiration_date%%\n\t</video:video>";

# Templates para sitemaps de noticias.
our $XML_NEWS_INDEX = 'sitemap_news.xml';
our $XML_NEWS_MOLDE1 = '<?xml version="1.0" encoding="UTF-8"?>
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"
    xmlns:news="http://www.google.com/schemas/sitemap-news/0.9"
    xmlns:image="http://www.google.com/schemas/sitemap-image/1.1"
    xmlns:video="http://www.google.com/schemas/sitemap-video/1.1">%%content%%
</urlset>';

our $XML_NEWS_MOLDE2 = '
    <url>
        <loc>%%loc%%</loc>
        <news:news>
            <news:publication>
                <news:name>%%sitename%%</news:name>
                <news:language>es</news:language>
            </news:publication>
            <news:publication_date>%%pub_date%%</news:publication_date>
            <news:title>%%titular%%</news:title>
            <news:keywords>%%keywords%%</news:keywords>
        </news:news>%%if_img_art%%
        <image:image>
            <image:loc>%%img_art%%</image:loc>%%if_caption%%
            <image:caption>%%caption_art%%</image:caption>%%/if_caption%%
        </image:image>%%/if_img_art%% %%if_img_port%%
        <image:image>
            <image:loc>%%img_port%%</image:loc>%%if_caption%%
            <image:caption>%%caption%%</image:caption>%%/if_caption%%
        </image:image>%%/if_img_port%%
    </url>';

# ---------------------------------------------------------------
# Devuelve la fecha actual
#   0) Time o numero de segundos desde 1970. Si no viene, se usa el time actual
#   Retorna: La fecha en formato yyyymmddhhmmss
sub getFechaHora {
    my ($mytime) = $_[0];
    my (@mylocaltime);

    if($mytime) {
        @mylocaltime = localtime($mytime);
    } else {
        @mylocaltime = localtime;
    }
        my $year    = $mylocaltime[5] + 1900;
    my $month   = $mylocaltime[4] + 1;
    my $day     = $mylocaltime[3];
    my $hour    = $mylocaltime[2];
    my $min     = $mylocaltime[1];
    my $sec     = $mylocaltime[0];

    $month = '0'.$month if($month<10);
    $day = '0'.$day if($day<10);

    $hour = '0'.$hour if($hour<10);
    $min = '0'.$min if($min<10);
    $sec = '0'.$sec if($sec<10);
    return "$year$month$day$hour$min$sec";
}

# ---------------------------------------------------------------
# Devuelve la fecha actual
#   0) Time o numero de segundos desde 1970. Si no viene, se usa el time actual
#   Retorna: La fecha en formato yyyy-mm-dd
sub getFecha {
    my ($mytime) = $_[0];
    my (@mylocaltime);

    if($mytime) {
        @mylocaltime = localtime($mytime);
    } else {
        @mylocaltime = localtime;
    }

    my $year    = $mylocaltime[5] + 1900;
    my $month   = $mylocaltime[4] + 1;
    my $day     = $mylocaltime[3];

    $month = '0'.$month if($month<10);
    $day = '0'.$day if($day<10);
    return "$year-$month-$day";
}

# ---------------------------------------------------------------
# Devuelve la fecha limite
#   0) Time o numero de segundos desde 1970. Si no viene, se usa el time actual
#   Retorna: La fecha en formato yyyymmddhhmm
sub getDesfaseHoras {
    my ($horas) = $_[0];
    my $hoursago = time - $horas*60*60;
    my @mylocaltime = localtime($hoursago);

    my $year    = $mylocaltime[5] + 1900;
    my $month   = $mylocaltime[4] + 1;
    my $day     = $mylocaltime[3];
    my $h       = $mylocaltime[2];
    my $m       = $mylocaltime[1];

    $month = '0'.$month if($month<10);
    $day = '0'.$day if($day<10);
    $h = '0'.$h if($h<10);
    $m = '0'.$m if($m<10);

    return "$year$month$day$h$m";
}

# ---------------------------------------------------------------
# Devuelve el limite 2 dias atras segun google
#   Retorna: La fecha en formato yyyymmddhhmm
sub getMaxHoursLimit {
    my $hoursago = time - 48*60*60;
    my @mylocaltime = localtime($hoursago);

    my $year    = $mylocaltime[5] + 1900;
    my $month   = $mylocaltime[4] + 1;
    my $day     = $mylocaltime[3];
    my $h       = $mylocaltime[2];
    my $m       = $mylocaltime[1];

    $month = '0'.$month if($month<10);
    $day = '0'.$day if($day<10);
    $h = '0'.$h if($h<10);
    $m = '0'.$m if($m<10);

    return "$year$month$day$h$m";
}

# ---------------------------------------------------------------
# Devuelve la fecha del archivo
#   0) Path al archivo
#   Retorna: La fecha en formato yyyy-mm-dd
sub getFechaArchivo {
    my ($filename) = $_[0];
    if(-f $filename) {
        my $mtime = (stat($filename))[9];
        return &getFecha($mtime);
    }
    return;
}

# ---------------------------------------------------------------
# Calcula el Timezone real
sub getOffsetGMT {
    my @t = localtime(time);
    my $gmt_offset_in_seconds = Time::Local::timegm(@t) - Time::Local::timelocal(@t);
    my $offset = $gmt_offset_in_seconds/3600;

    if ($offset =~ /^(-?)(\d+)$/) {
        my $sign = $1;
        my $num = $2;
        if($num >= 10) {
            $lib_sitemap::offset = $sign . $num . ':00';
        } else {
            $lib_sitemap::offset = $sign . '0' . $num . ':00';
        }
    } else {
        $lib_sitemap::offset = '-04:00';
    }
}

# ---------------------------------------------------------------
# Devuelve la fecha/hora de publicación del articulo en formato
# "News": 2008-06-07T22:41:45-04:00
#   0) Fecha de Publicación
#   1) Hora de Publicación
#   2) flag para insertar un número de segundos random.
#   Retorna: La fecha en el formato descrito
sub getFechaNews {
    my ($fechap, $horap, $flagsegs) = ($_[0], $_[1], $_[2]);
    my $mydate;

    if($fechap ne '' && $horap ne '') {

        return unless($fechap =~ /^(\d\d\d\d)(\d\d)(\d\d)$/);
        my $year    = $1;
        my $month   = $2;
        my $day     = $3;
        my $sec;

        return unless($horap =~ /^(\d\d)(\d\d)$/);
        my $hour    = $1;
        my $min     = $2;
        if($flagsegs) {
            $sec    = int(rand(60));
            $sec = '0'.$sec if($sec < 10);
        } else {
            $sec    = '00';
        }

        if($lib_sitemap::offsetGMT eq '') {
            $lib_sitemap::offsetGMT = &lib_sitemap::getOffsetGMT();
        }

        $mydate = "$year-$month-${day}T$hour:$min:$sec$lib_sitemap::offset";
    }
    return $mydate;
}

# ---------------------------------------------------------------
# Devuelve la fecha de modificación del archivo en formato
# "News": 2008-06-07T22:41:45-04:00
#   0) Path al archivo
#   Retorna: La fecha en el formato descrito
sub getFechaArchivoNews {
    my ($filename) = $_[0];
    my $mydate;

    if(-f $filename) {
        my @mylocaltime = localtime((stat($filename))[9]);
        my $year    = $mylocaltime[5] + 1900;
        my $month   = $mylocaltime[4] + 1;
        my $day     = $mylocaltime[3];
        my $hour     = $mylocaltime[2];
        my $min     = $mylocaltime[1];
        my $sec     = $mylocaltime[0];

        $month  = '0'.$month    if($month<10);
        $day    = '0'.$day      if($day<10);
        $hour   = '0'.$hour     if($hour<10);
        $min    = '0'.$min      if($min<10);
        $sec    = '0'.$sec      if($sec<10);

        $mydate = "$year-$month-${day}T$hour:$min:$sec-04:00";
    }
    return $mydate
}

# Convierte una string de timestamp perl, a una fecha en formato ISO 8601.
# param: string número de segundos desde el epoch
# retorna: string timestamp formato ISO 8601 o ''
# Transforma un epoch al formato ISO 8601, UTC: "%Y-%m-%dT%H:%M:%SZ"
sub epochToISO8601 {
    my $epoch = $_[0];
    my @utc = gmtime($epoch);
    return sprintf('%04d-%02d-%02dT%02d:%02d:%02dZ',(1900 + $utc[5]),(1 + $utc[4]),$utc[3],$utc[2],$utc[1],$utc[0]);
}

# ---------------------------------------------------------------
# Devuelve la frecuencia según fecha de modificación
#   0) Path al archivo
#   Retorna: La frecuencia. daily, weekly, monthly, yearly
sub getFrecuencia {
    my ($filename) = $_[0];

    my $onedayago = 60*60*24;
    my $oneweekago = $onedayago*7;
    my $onemonthago = $onedayago*30;

    if(-f $filename) {
        my $diff = (time) - (stat($filename))[9];
        if($diff < $onedayago) {
            return "daily";
        } elsif($diff < $oneweekago) {
            return "weekly";
        } elsif($diff < $onemonthago) {
            return "monthly";
        } else {
            return "yearly";
        }
    }
    return "";
}

# ---------------------------------------------------------------
# Obtiene las KeyWords asociadas al Artículo, escapeadas.
#   0) Nombre de la sección del Artículo
#   1) Nombre del tema asociado al Artículo
#   2) Nombre del subtema del Artículo
#   Retorna: Las Keywords del Artículo, escapeadas
sub getKeyWords {
    my ($secc, $tema, $stema) = (@_);
    my ($texto);
    if($secc ne '') {
        $texto = lib_utils::escape_xml($secc);
        if($tema ne '') {
            $texto = $texto .', '. lib_utils::escape_xml($tema);
            if($stema ne '') {
                $texto = $texto .', '. lib_utils::escape_xml($stema);
            }
        }
    }
    return $texto;
}

# ---------------------------------------------------------------
# Si el Prontus tiene Multiedicion, Obtiene la Edicion Vigente.
# Si no, devuelve 'base'
sub getEdicVigente {
    my ($docroot, $prontusid) = ($_[0], $_[1]);
    my $rutaEdicFile = $docroot .'/'. $prontusid . '/cpan/data/ed_vigente.txt';

    if ($prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTI_EDICION'} eq 'NO') {
        my $NomEdic = glib_fildir_03::read_file($rutaEdicFile);
        if ($NomEdic =~ /^\d{4}_\d{2}_\d{2}_\d{1,}$/) {
            return $NomEdic;
        } else {
            return 'base';
        }
    } else {
        return 'base';
    }
}

sub get_xml_pags_index {
    return $XML_PAGS_INDEX;
}

sub get_xml_news_index {
    return $XML_NEWS_INDEX;
}

return 1;

==> release.12.3.1.2.tgz: cgi-cpn/sitemaps/lib_sitemap.pm <==
#!/usr/bin/perl

# -------------------------------COMENTARIO GLOBAL---------------
# PROPOSITO.
# -----------
# Funciones utilitarias para la creación de Site Maps y News Site Maps
# ---------------------------------------------------------------
# Requiere
# use Time::Local;

use utf8;
use strict;

package lib_sitemap;

# Cantidad máxima de archivos de sitemap por index:
# Si hay más URLs que SITEMAP_NRO_MAX_PAGS en el listado, se dividen los sitemaps en múltiples archivos y se genera un index que las engloba.
# Ver https://support.google.com/webmasters/answer/75712?visit_id=637273939996212081-1472635633&rd=1
our $MAX_SITEMAP_FILES = 500; # número recomendado por google.

# Path de archivos y directorios
our $PATH_DIR = '/sitemap/';
our $XML_PAGS_INDEX = 'sitemap_pags.xml';
our $XML_PAGS_INDEX_IMAGE = 'sitemap_pags_images.xml'; # solo para sitemaps separados.
our $XML_PAGS_INDEX_VIDEO = 'sitemap_pags_videos.xml'; # solo para sitemaps separados.

our $XML_PAGS_NAME_TEMPLATE = 'sitemap_pags_%%anio_mes%%.xml';
our $XML_PAGS_NAME_TEMPLATE_IMAGE = 'sitemap_pags_images_%%anio_mes%%.xml'; # solo para sitemaps separados.
our $XML_PAGS_NAME_TEMPLATE_VIDEO = 'sitemap_pags_videos_%%anio_mes%%.xml'; # solo para sitemaps separados.

# Templates para cada sitemap de páginas
our $XML_PAGS_MOLDE1 = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\" xmlns:image=\"http://www.google.com/schemas/sitemap-image/1.1\" xmlns:video=\"http://www.google.com/schemas/sitemap-video/1.1\">\n%%content%%</urlset>\n";
# Moldes para XML de artículos con videos e imágenes.
our $XML_PAGS_MOLDE2 = "<url>\n\t<loc>%%loc%%</loc><lastmod>%%lastmod%%</lastmod>%%images%%%%videos%%\n</url>\n"; # sitemap base. Si va separado en tres sitemaps, se descartan %%images%% y %%videos%%
our $XML_PAGS_MOLDE2_IMAGE = "%%url%%<url>\n\t<loc>%%loc%%</loc><lastmod>%%lastmod%%</lastmod>%%images%%\n</url>\n%%/url%%"; # solo para sitemaps separados
our $XML_PAGS_MOLDE2_VIDEO = "%%url%%<url>\n\t<loc>%%loc%%</loc><lastmod>%%lastmod%%</lastmod>%%videos%%\n</url>\n%%/url%%"; # solo para sitemaps separados

# Templates para el index de sitemaps
our $XML_GLOBAL_MOLDE1 = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<sitemapindex xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\" xmlns:image=\"http://www.google.com/schemas/sitemap-image/1.1\" xmlns:video=\"http://www.google.com/schemas/sitemap-video/1.1\">\n%%content%%</sitemapindex>\n";
our $XML_GLOBAL_MOLDE2 = "<sitemap>\n\t<loc>%%loc%%</loc>\n\t<lastmod>%%lastmod%%</lastmod>\n</sitemap>\n";

our $XML_GLOBAL_IMAGE = "\n\t<image:image>\n\t\t<image:loc>%%loc%%</image:loc>\n\t\t<image:title>%%title%%</image:title>\n\t</image:image>";
our $XML_GLOBAL_VIDEO = "\n\t<video:video>\n\t\t<video:thumbnail_loc>%%thumbnail%%</video:thumbnail_loc>\n\t\t<video:title>%%title%%</video:title>\n\t\t<video:description>%%description%%</video:description>\n\t\t<video:content_loc>%%content_loc%%</video:content_loc>\n\t\t<video:publication_date>%%publication_date%%</video:publication_date>%%expiration_date%%\n\t</video:video>";

# Templates para sitemaps de noticias.
our $XML_NEWS_INDEX = 'sitemap_news.xml';
our $XML_NEWS_MOLDE1 = '<?xml version="1.0" encoding="UTF-8"?>
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"
    xmlns:news="http://www.google.com/schemas/sitemap-news/0.9"
    xmlns:image="http://www.google.com/schemas/sitemap-image/1.1"
    xmlns:video="http://www.google.com/schemas/sitemap-video/1.1">%%content%%
</urlset>';

our $XML_NEWS_MOLDE2 = '
    <url>
        <loc>%%loc%%</loc>
        <news:news>
            <news:publication>
                <news:name>%%sitename%%</news:name>
                <news:language>es</news:language>
            </news:publication>
            <news:publication_date>%%pub_date%%</news:publication_date>
            <news:title>%%titular%%</news:title>
            <news:keywords>%%keywords%%</news:keywords>
        </news:news>%%if_img_art%%
        <image:image>
            <image:loc>%%img_art%%</image:loc>%%if_caption%%
            <image:caption>%%caption_art%%</image:caption>%%/if_caption%%
        </image:image>%%/if_img_art%% %%if_img_port%%
        <image:image>
            <image:loc>%%img_port%%</image:loc>%%if_caption%%
            <image:caption>%%caption%%</image:caption>%%/if_caption%%
        </image:image>%%/if_img_port%%
    </url>';

# Devuelve la fecha actual
#   0) Time o numero de segundos desde 1970. Si no viene, se usa el time actual
#   Retorna: La fecha en formato yyyy-mm-dd
sub getFecha {
    my ($mytime) = $_[0];
    my (@mylocaltime);

    if($mytime) {
        @mylocaltime = localtime($mytime);
    } else {
        @mylocaltime = localtime;
    }

    my $year    = $mylocaltime[5] + 1900;
    my $month   = $mylocaltime[4] + 1;
    my $day     = $mylocaltime[3];

    $month = '0'.$month if($month<10);
    $day = '0'.$day if($day<10);
    return "$year-$month-$day";
}


# Devuelve la fecha limite
#   0) Time o numero de segundos desde 1970. Si no viene, se usa el time actual
#   Retorna: La fecha en formato yyyymmddhhmm
sub getDesfaseHoras {
    my ($horas) = $_[0];
    my $hoursago = time - $horas*60*60;
    my @mylocaltime = localtime($hoursago);

    my $year    = $mylocaltime[5] + 1900;
    my $month   = $mylocaltime[4] + 1;
    my $day     = $mylocaltime[3];
    my $h       = $mylocaltime[2];
    my $m       = $mylocaltime[1];

    $month = '0'.$month if($month<10);
    $day = '0'.$day if($day<10);
    $h = '0'.$h if($h<10);
    $m = '0'.$m if($m<10);

    return "$year$month$day$h$m";
}

# Devuelve el limite 2 dias atras segun google
#   Retorna: La fecha en formato yyyymmddhhmm
sub getMaxHoursLimit {
    my $hoursago = time - 48*60*60;
    my @mylocaltime = localtime($hoursago);

    my $year    = $mylocaltime[5] + 1900;
    my $month   = $mylocaltime[4] + 1;
    my $day     = $mylocaltime[3];
    my $h       = $mylocaltime[2];
    my $m       = $mylocaltime[1];

    $month = '0'.$month if($month<10);
    $day = '0'.$day if($day<10);
    $h = '0'.$h if($h<10);
    $m = '0'.$m if($m<10);

    return "$year$month$day$h$m";
}

# Devuelve la fecha del archivo
#   0) Path al archivo
#   Retorna: La fecha en formato yyyy-mm-dd
sub getFechaArchivo {
    my ($filename) = $_[0];
    if(-f $filename) {
        my $mtime = (stat($filename))[9];
        return &getFecha($mtime);
    }
    return;
}

# Calcula el Timezone real
sub getOffsetGMT {
    my @t = localtime(time);
    my $gmt_offset_in_seconds = Time::Local::timegm(@t) - Time::Local::timelocal(@t);
    my $offset = $gmt_offset_in_seconds/3600;

    if ($offset =~ /^(-?)(\d+)$/) {
        my $sign = $1;
        my $num = $2;
        if($num >= 10) {
            $lib_sitemap::offset = $sign . $num . ':00';
        } else {
            $lib_sitemap::offset = $sign . '0' . $num . ':00';
        }
    } else {
        $lib_sitemap::offset = '-04:00';
    }
}

# Devuelve la fecha/hora de publicación del articulo en formato
# "News": 2008-06-07T22:41:45-04:00
#   0) Fecha de Publicación
#   1) Hora de Publicación
#   2) flag para insertar un número de segundos random.
#   Retorna: La fecha en el formato descrito
sub getFechaNews {
    my ($fechap, $horap, $flagsegs) = ($_[0], $_[1], $_[2]);
    my $mydate;

    if($fechap ne '' && $horap ne '') {

        return unless($fechap =~ /^(\d\d\d\d)(\d\d)(\d\d)$/);
        my $year    = $1;
        my $month   = $2;
        my $day     = $3;
        my $sec;

        return unless($horap =~ /^(\d\d)(\d\d)$/);
        my $hour    = $1;
        my $min     = $2;
        if($flagsegs) {
            $sec    = int(rand(60));
            $sec = '0'.$sec if($sec < 10);
        } else {
            $sec    = '00';
        }

        if($lib_sitemap::offsetGMT eq '') {
            $lib_sitemap::offsetGMT = &lib_sitemap::getOffsetGMT();
        }

        $mydate = "$year-$month-${day}T$hour:$min:$sec$lib_sitemap::offset";
    }
    return $mydate;
}

# Devuelve la fecha de modificación del archivo en formato
# "News": 2008-06-07T22:41:45-04:00
#   0) Path al archivo
#   Retorna: La fecha en el formato descrito
sub getFechaArchivoNews {
    my ($filename) = $_[0];
    my $mydate;

    if(-f $filename) {
        my @mylocaltime = localtime((stat($filename))[9]);
        my $year    = $mylocaltime[5] + 1900;
        my $month   = $mylocaltime[4] + 1;
        my $day     = $mylocaltime[3];
        my $hour     = $mylocaltime[2];
        my $min     = $mylocaltime[1];
        my $sec     = $mylocaltime[0];

        $month  = '0'.$month    if($month<10);
        $day    = '0'.$day      if($day<10);
        $hour   = '0'.$hour     if($hour<10);
        $min    = '0'.$min      if($min<10);
        $sec    = '0'.$sec      if($sec<10);

        $mydate = "$year-$month-${day}T$hour:$min:$sec-04:00";
    }
    return $mydate
}

# Devuelve la frecuencia según fecha de modificación
#   0) Path al archivo
#   Retorna: La frecuencia. daily, weekly, monthly, yearly
sub getFrecuencia {
    my ($filename) = $_[0];

    my $onedayago = 60*60*24;
    my $oneweekago = $onedayago*7;
    my $onemonthago = $onedayago*30;

    if(-f $filename) {
        my $diff = (time) - (stat($filename))[9];
        if($diff < $onedayago) {
            return "daily";
        } elsif($diff < $oneweekago) {
            return "weekly";
        } elsif($diff < $onemonthago) {
            return "monthly";
        } else {
            return "yearly";
        }
    }
    return "";
}

# Obtiene las KeyWords asociadas al Artículo, escapeadas.
#   0) Nombre de la sección del Artículo
#   1) Nombre del tema asociado al Artículo
#   2) Nombre del subtema del Artículo
#   Retorna: Las Keywords del Artículo, escapeadas
sub getKeyWords {
    my ($secc, $tema, $stema) = (@_);
    my ($texto);
    if($secc ne '') {
        $texto = lib_encodes::escape_xml($secc);
        if($tema ne '') {
            $texto = $texto .', '. lib_encodes::escape_xml($tema);
            if($stema ne '') {
                $texto = $texto .', '. lib_encodes::escape_xml($stema);
            }
        }
    }
    return $texto;
}

# Si el Prontus tiene Multiedicion, Obtiene la Edicion Vigente.
# Si no, devuelve 'base'
sub getEdicVigente {
    my ($docroot, $prontusid) = ($_[0], $_[1]);
    my $rutaEdicFile = $docroot .'/'. $prontusid . '/cpan/data/ed_vigente.txt';

    if ($prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTI_EDICION'} eq 'NO') {
        my $NomEdic = glib_fildir_03::read_file($rutaEdicFile);
        if ($NomEdic =~ /^\d{4}_\d{2}_\d{2}_\d{1,}$/) {
            return $NomEdic;
        } else {
            return 'base';
        }
    } else {
        return 'base';
    }
}

sub get_xml_pags_index {
    return $XML_PAGS_INDEX;
}

sub get_xml_news_index {
    return $XML_NEWS_INDEX;
}

1;
